# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
## [v0.1.0] - 2025-09-24
## [v0.1.2] - 2025-09-24

- No changes

## [v0.1.1] - 2025-09-24

- No changes


## 🔄 Other Changes

- Refactor/remove relative imports (#3) @amankumarsingh77
- Refact: Rename project and minor changes (#4) @amankumarsingh77



